@@ -60,7 +60,7 @@ def get_efficiency(browser, season=None):
 	# Remove the header rows that are interjected for readability.
 	eff_df = eff_df[eff_df.Team != 'Team']
 	# Remove NCAA tourny seeds for previous seasons.
-	eff_df['Team'] = eff_df['Team'].str.replace('\d+', '')
+	eff_df['Team'] = eff_df['Team'].str.replace(r'\d+', '', regex=True)
 	eff_df['Team'] = eff_df['Team'].str.rstrip()
 	eff_df = eff_df.dropna()
 
@@ -108,7 +108,7 @@ def get_fourfactors(browser, season=None):
 	# Remove the header rows that are interjected for readability.
 	ff_df = ff_df[ff_df.Team != 'Team']
 	# Remove NCAA tourny seeds for previous seasons.
-	ff_df['Team'] = ff_df['Team'].str.replace('\d+', '')
+	ff_df['Team'] = ff_df['Team'].str.replace(r'\d+', '', regex=True)
 	ff_df['Team'] = ff_df['Team'].str.rstrip()
 	ff_df = ff_df.dropna()
 
@@ -147,7 +147,7 @@ def get_teamstats(browser, defense=False, season=None):
 			url = url + '&od=d'
 			last_cols = ['AdjDE', 'AdjDE.Rank']
 	elif defense:
-		url = url + '&od=d'
+		url = url + '?od=d'
 		last_cols = ['AdjDE', 'AdjDE.Rank']
 
 	browser.open(url)
@@ -165,7 +165,7 @@ def get_teamstats(browser, defense=False, season=None):
 	# Remove the header rows that are interjected for readability.
 	ts_df = ts_df[ts_df.Team != 'Team']
 	# Remove NCAA tourny seeds for previous seasons.
-	ts_df['Team'] = ts_df['Team'].str.replace('\d+', '')
+	ts_df['Team'] = ts_df['Team'].str.replace(r'\d+', '', regex=True)
 	ts_df['Team'] = ts_df['Team'].str.rstrip()
 	ts_df = ts_df.dropna()
 
@@ -212,7 +212,7 @@ def get_pointdist(browser, season=None):
 	# Remove the header rows that are interjected for readability.
 	dist_df = dist_df[dist_df.Team != 'Team']
 	# Remove NCAA tourny seeds for previous seasons.
-	dist_df['Team'] = dist_df['Team'].str.replace('\d+', '')
+	dist_df['Team'] = dist_df['Team'].str.replace(r'\d+', '', regex=True)
 	dist_df['Team'] = dist_df['Team'].str.rstrip()
 	dist_df = dist_df.dropna()
 
@@ -269,7 +269,7 @@ def get_height(browser, season=None):
 	# Remove the header rows that are interjected for readability.
 	h_df = h_df[h_df.Team != 'Team']
 	# Remove NCAA tourny seeds for previous seasons.
-	h_df['Team'] = h_df['Team'].str.replace('\d+', '')
+	h_df['Team'] = h_df['Team'].str.replace(r'\d+', '', regex=True)
 	h_df['Team'] = h_df['Team'].str.rstrip()
 	h_df = h_df.dropna()
 
@@ -351,7 +351,7 @@ def get_playerstats(browser, season=None, metric='EFG', conf=None, conf_only=Fal
 			
 			# Split ortg column.
 			ps_df.columns = ['Rank', 'Player', 'Team', 'ORtg', 'Ht', 'Wt', 'Yr']
-			ps_df['ORtg'], ps_df['Poss%'] = ps_df['ORtg'].str.split(' ', 1).str
+			ps_df[['ORtg', 'Poss%']] = ps_df['ORtg'].str.split(' ', 1, expand=True)
 			ps_df['Poss%'] = ps_df['Poss%'].str.strip('()')
 
 			ps_df = ps_df[ps_df.Rank != 'Rk']
@@ -421,10 +421,10 @@ def get_kpoy(browser, season=None):
 	kpoy_df.columns = ['Rank', 'Player', 'KPOY Rating']
 
 	# Some mildly moronic dataframe tidying.
-	kpoy_df['Player'], kpoy_df['Weight'], kpoy_df['Year'], kpoy_df['Hometown'] = kpoy_df['Player'].str.split(' · ').str
-	kpoy_df['Player'], kpoy_df['Info'] = kpoy_df['Player'].str.split(', ', 1).str
-	kpoy_df['Team'] = kpoy_df['Info'].str.replace('\d+', '').str.rstrip('-')
-	kpoy_df['Height'] = kpoy_df['Info'].str.replace(r'[a-z]+', '', flags=re.IGNORECASE).str.strip('. ').str.strip()
+	kpoy_df[['Player', 'Weight', 'Year', 'Hometown']] = kpoy_df['Player'].str.split(' · ', expand=True)
+	kpoy_df[['Player', 'Info']] = kpoy_df['Player'].str.split(', ', 1, expand=True)
+	kpoy_df['Team'] = kpoy_df['Info'].str.replace(r'\d+', '', regex=True).str.rstrip('-')
+	kpoy_df['Height'] = kpoy_df['Info'].str.replace(r'[a-z]+', '', flags=re.IGNORECASE, regex=True).str.strip('. ').str.strip()
 	kpoy_df = kpoy_df.drop(['Info'], axis=1)
 
 	kpoy_dfs.append(kpoy_df)
@@ -437,10 +437,10 @@ def get_kpoy(browser, season=None):
 		mvp_df.columns = ['Rank', 'Player', 'Game MVPs']
 
 		# More tidying.
-		mvp_df['Player'], mvp_df['Weight'], mvp_df['Year'], mvp_df['Hometown'] = mvp_df['Player'].str.split(' · ').str
-		mvp_df['Player'], mvp_df['Info'] = mvp_df['Player'].str.split(', ', 1).str
-		mvp_df['Team'] = mvp_df['Info'].str.replace('\d+', '').str.rstrip('-')
-		mvp_df['Height'] = mvp_df['Info'].str.replace(r'[a-z]+', '', flags=re.IGNORECASE).str.strip('. ').str.strip()
+		mvp_df[['Player', 'Weight', 'Year', 'Hometown']] = mvp_df['Player'].str.split(' · ', expand=True)
+		mvp_df[['Player', 'Info']] = mvp_df['Player'].str.split(', ', 1, expand=True)
+		mvp_df['Team'] = mvp_df['Info'].str.replace(r'\d+', '', regex=True).str.rstrip('-')
+		mvp_df['Height'] = mvp_df['Info'].str.replace(r'[a-z]+', '', flags=re.IGNORECASE, regex=True).str.strip('. ').str.strip()
 		mvp_df = mvp_df.drop(['Info'], axis=1)
 
 		kpoy_dfs.append(mvp_df)
